@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 # cal.pl --- Simple calendar
-# Last modify Time-stamp: <Ye Wenbin 2007-07-14 14:31:03>
+# Last modify Time-stamp: <Ye Wenbin 2006-12-17 22:01:56>
 # Version: v 0.0 <2006-12-16 23:49:45>
 # Author: Ye Wenbin <wenbinye@163.com>
 
@@ -9,12 +9,9 @@ use warnings;
 use Pod::Usage;
 use Getopt::Long qw(:config auto_help);
 use Calendar::Calendar qw(:all);
-use I18N::Langinfo;
 
 my %Config = (
-    'locale' => langinfo(I18N::Langinfo::CODESET()),
-    'weekstart' => 0,
-    'type' => 'gregorian',
+    'locale' => ($^O =~/dos|mswin/i ? 'cp936' : 'utf8'),
 );
 
 my ($month, $year, $type, $china, $gregorian, $julian);
@@ -48,10 +45,8 @@ if ( $china) {
 } elsif ( $julian ) {
     $type = "Julian";
 }
-$type = ucfirst($type);
-
 ## ensure the package is implement
-unless ( defined($type) && grep { $type eq $_ } qw(China Gregorian Julian) ) {
+unless ( defined($type) && grep { $type =~ /$_/ } qw(China Gregorian Julian) ) {
     pod2usage();
 }
 
@@ -118,10 +113,6 @@ cal.pl [-l locale -w weekstart [-c|-g|-j|-t calendar_type] month year]
 
        cal.pl -c -l gbk
 
-=head1 Configuration
-
-Add your default command parameter to the %Config in this file.
-
 =head1 AUTHOR
 
 Ye Wenbin <wenbinye@gmail.com>
