@@ -1,4 +1,5 @@
 # Calendar.pm --- 
+# Last modify Time-stamp: <Ye Wenbin 2006-12-17 21:14:57>
 # Version: v 0.0 <2006-12-15 14:37:46>
 # Author: Ye Wenbin <wenbinye@163.com>
 
@@ -14,7 +15,7 @@ use overload
     '0+' => \&absolute_date;
 
 use vars qw($VERSION);
-use version; our $VERSION=qv("0.4.2");
+$VERSION="0.01";
 
 sub new {
     my $_class = shift;
@@ -109,46 +110,41 @@ sub add {
 #}}}
 
 sub AUTOLOAD {
-    no strict 'refs';
-    our ($AUTOLOAD);
+    use vars qw($AUTOLOAD);
     if ( $AUTOLOAD =~ /::new_from_(\w+)/ ) {
-        my $subname = "Calendar::new_from_" . $1;
-        my $module = "Calendar::" . $1;
-        eval("require $module");
+        my $self = shift;
+        my $module = $1;
+        my $code = <<CODE;
+require Calendar::$module;
+Calendar::$module->new(\@_);
+CODE
+
+        $self = eval $code;
         if ( $@ ) {
-            die "Can't load module $module: $@!\n"
+            die "Can't load module Calendar::$module: $@!\n"
         }
-        my $sub = *{$subname} = sub {
-            my $self = shift;
-            return $module->new(@_);
-        };
-        goto &$sub;
+        return $self;
     }
     elsif ( $AUTOLOAD =~ /::convert_to_(\w+)/ ) {
-        my $subname = "Calendar::convert_to_" . $1;
-        my $module = "Calendar::" . $1;
-        eval("require $module");
+        my $self = \$_[0];
+        my $module = $1;
+        my $code = <<CODE;
+require Calendar::$module;
+Calendar::$module->new(\$\$self->absolute_date);
+CODE
+        $$self = eval $code;
         if ( $@ ) {
-            die "Can't load module $module: $@!\n"
+            die "Can't load module Calendar::$module: $@!\n"
         }
-        my $sub = *{$subname} = sub {
-            $_[0] = $module->new($_[0]->absolute_date);
-            return $_[0];
-        };
-        goto &$sub;
+        return $$self;
     }
-    elsif ( $AUTOLOAD =~ /::(year|month|day)$/ ) {
+    elsif ( $AUTOLOAD =~ /::(year|month|day)/ ) {
         my $self = shift;
         if ( exists $self->{$1} ) {
             return $self->{$1};
         }
         return;
     }
-    elsif ( $AUTOLOAD =~ /DESTROY/) {
-    }
-    else {
-        die "Unknown function $AUTOLOAD\n";
-    }
 }
 
 1;
@@ -166,7 +162,7 @@ Calendar - Perl extension for calendar convertion
    print $date->date_string("Gregorian date: %M %W %d %Y"), "\n";
 
    my $newdate = $date + 7;
-   print $newdate->date_string("Gregorian date of next week: %D"), "\n";
+   print $date->date_string("Gregorian date of next week: %D"), "\n";
    
    $newdate = $date-7;
    print $newdate->date_string("Absolute date of last week: %A\n");
@@ -280,7 +276,7 @@ specifications as following:
    %d       numeric day of the month, with leading zeros (eg 01..31)
    %D       MM/DD/YY
    %m       month number, with leading zeros (eg 01..31)
-   %M       month name
+   %M       month numer
    %W       day of the week
    %Y       year
 
@@ -289,11 +285,9 @@ For chinese calendar, the following specifications are available:
    %S       sexagesimal name, eg. "丙戌"
    %D       day name, eg. "初二"
    %Z       zodiac name, eg. "狗"
-   %M       month name in chinese, eg. "十一月"
+   %m       month name in chinese, eg. "十一月"
    %W       week day name in chinese, eg. "星期一"
 
-Meanwhile, %Y, %m and %d now stand for Gregorian year, month and day.
-
 =head2 Other method
 
 =over 4
